@@ -9,6 +9,7 @@ Supports:
 - Caching for repeated conversions
 """
 
+import inspect
 import logging
 import types
 from enum import Enum
@@ -62,6 +63,16 @@ T = TypeVar("T", bound=type)
 logger = logging.getLogger(__name__)
 
 
+def _clean_docstring(docstring: str | None) -> str | None:
+    """Clean and format a docstring for use in GraphQL schema descriptions.
+
+    Uses Python's inspect.cleandoc to properly handle indentation and whitespace.
+    """
+    if not docstring:
+        return None
+    return inspect.cleandoc(docstring)
+
+
 def _convert_fraise_union(
     typ: type[Any],
     annotation: FraiseUnion,
@@ -729,6 +740,7 @@ def convert_type_to_graphql_output(
                     fields=gql_fields,
                     interfaces=interfaces if interfaces else None,
                     is_type_of=is_type_of,
+                    description=_clean_docstring(typ.__doc__),
                 )
                 _graphql_type_cache[key] = gql_type
                 return gql_type
@@ -767,7 +779,7 @@ def convert_type_to_graphql_output(
                     name=typ.__name__,
                     fields=gql_fields,
                     resolve_type=resolve_type,
-                    description=typ.__doc__,
+                    description=_clean_docstring(typ.__doc__),
                 )
                 _graphql_type_cache[key] = gql_type
                 return gql_type
