@@ -2,12 +2,15 @@
 
 import re
 from enum import Enum
-from typing import Any, Dict, Optional
+from typing import TYPE_CHECKING, Any, Dict, Optional
 
 from fraiseql.analysis.query_analyzer import QueryAnalyzer
 from fraiseql.fastapi.config import FraiseQLConfig
 from fraiseql.fastapi.turbo import TurboRegistry
 
+if TYPE_CHECKING:
+    from fraiseql.routing.query_router import QueryRouter
+
 
 class ExecutionMode(Enum):
     """Query execution modes."""
@@ -29,6 +32,7 @@ class ModeSelector:
         self.config = config
         self.turbo_registry: Optional[TurboRegistry] = None
         self.query_analyzer: Optional[QueryAnalyzer] = None
+        self.query_router: Optional[QueryRouter] = None
         self.mode_hint_pattern = re.compile(
             getattr(config, "mode_hint_pattern", r"#\s*@mode:\s*(\w+)")
         )
@@ -49,6 +53,14 @@ class ModeSelector:
         """
         self.query_analyzer = analyzer
 
+    def set_query_router(self, router: "QueryRouter"):
+        """Set query router for entity-aware routing.
+
+        Args:
+            router: QueryRouter instance
+        """
+        self.query_router = router
+
     def select_mode(
         self, query: str, variables: Dict[str, Any], context: Dict[str, Any]
     ) -> ExecutionMode:
@@ -68,6 +80,16 @@ class ModeSelector:
             if mode_hint:
                 return mode_hint
 
+        # Check entity routing if available and enabled
+        if (
+            self.query_router
+            and hasattr(self.config, "entity_routing")
+            and self.config.entity_routing
+        ):
+            entity_mode = self.query_router.determine_execution_mode(query)
+            if entity_mode is not None:
+                return entity_mode
+
         # Check mode priority from config
         execution_mode_priority = getattr(
             self.config, "execution_mode_priority", ["turbo", "passthrough", "normal"]
