@@ -29,6 +29,32 @@ def _extract_type(field_type: Any) -> Any:
     return field_type
 
 
+def _serialize_field_value(field_value: Any) -> Any:
+    """Helper function to serialize a field value recursively.
+
+    Handles nested FraiseQL objects, lists, and primitive values.
+    Uses the existing serialization logic from the SQL generator.
+    """
+    # Import here to avoid circular imports
+    from fraiseql.mutations.sql_generator import _serialize_basic
+
+    # Handle nested FraiseQL input objects
+    if hasattr(field_value, "to_dict") and callable(field_value.to_dict):
+        return field_value.to_dict()
+
+    # Handle lists of FraiseQL objects or primitives
+    if isinstance(field_value, list):
+        return [
+            item.to_dict()
+            if (hasattr(item, "to_dict") and callable(item.to_dict))
+            else _serialize_basic(item)
+            for item in field_value
+        ]
+
+    # Handle primitive values using existing serialization logic
+    return _serialize_basic(field_value)
+
+
 def _process_field_value(value: Any, field_type: Any) -> Any:
     """Process a field value based on its type hint.
 
@@ -112,13 +138,18 @@ def define_fraiseql_type(
                 field.purpose = "output"
 
     typed_cls.__annotations__ = patched_annotations
-    typed_cls.__init__ = make_init(field_map, kw_only=True)
+    typed_cls.__init__ = make_init(field_map, kw_only=True, type_kind=kind)
 
     # Set FraiseQL runtime metadata
     typed_cls.__gql_typename__ = typed_cls.__name__
     typed_cls.__gql_fields__ = field_map
     typed_cls.__gql_type_hints__ = type_hints
 
+    # Apply automatic field descriptions for fields without explicit descriptions
+    from fraiseql.utils.field_descriptions import apply_auto_descriptions
+
+    apply_auto_descriptions(typed_cls)
+
     definition = FraiseQLTypeDefinition(
         python_type=typed_cls,
         is_input=(kind == "input"),
@@ -167,4 +198,29 @@ def define_fraiseql_type(
 
         typed_cls.from_dict = from_dict
 
+    # Add JSON serialization methods for input types
+    if kind == "input":
+
+        def to_dict(self) -> dict[str, Any]:
+            """Convert FraiseQL input object to dictionary for JSON serialization.
+
+            Excludes UNSET values and handles nested FraiseQL objects recursively.
+            """
+            from fraiseql.types.definitions import UNSET
+
+            result = {}
+            for field_name in getattr(self, "__annotations__", {}):
+                if hasattr(self, field_name):
+                    field_value = getattr(self, field_name)
+                    if field_value is not UNSET:
+                        result[field_name] = _serialize_field_value(field_value)
+            return result
+
+        def __json__(self) -> dict[str, Any]:  # noqa: N807
+            """JSON serialization method for FraiseQL input objects."""
+            return self.to_dict()
+
+        typed_cls.to_dict = to_dict
+        typed_cls.__json__ = __json__
+
     return cast("type[T]", typed_cls)
